Package: agrmt
Version: 1.42.19
Date: 2026-04-08
Title: Calculate Concentration and Dispersion in Ordered Rating Scales
Authors@R: c(person(given = "Didier",
                  family = "Ruedin",
                  role = c("aut", "cre"),
                  email = "didier.ruedin@unine.ch",
                  comment = c(ORCID = "0000-0001-5213-4316")),
              person(given = "Clem",
                     family = "Aeppli",
                     role = "ctb",
                     comment = c(ORCID = "0000-0002-4003-7938")))
Maintainer: Didier Ruedin <didier.ruedin@unine.ch>
Description: Calculates concentration and dispersion in ordered rating scales. It implements various measures of concentration and dispersion to describe what researchers variably call agreement, concentration, consensus, dispersion, or polarization among respondents in ordered data. It also implements other related measures to classify distributions. In addition to a generic city-block based concentration measure and a generic dispersion measure, the package implements various measures, including van der Eijk's (2001) <DOI: 10.1023/A:1010374114305> measure of agreement A, measures of concentration by Leik, Tatsle and Wierman, Blair and Lacy, Kvalseth, Berry and Mielke, Reardon, and Garcia-Montalvo and Reynal-Querol. Furthermore, the package provides an implementation of Galtungs AJUS-system to classify distributions, as well as a function to identify the position of multiple modes.
License: MIT + file LICENSE
URL: http://agrmt.r-forge.r-project.org
NeedsCompilation: no
Packaged: 2026-04-08 08:00:52 UTC; didier
Author: Didier Ruedin [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5213-4316>),
  Clem Aeppli [ctb] (ORCID: <https://orcid.org/0000-0002-4003-7938>)
Repository: CRAN
Date/Publication: 2026-04-08 21:40:02 UTC
Built: R 4.5.2; ; 2026-04-08 22:24:32 UTC; unix
